@@ -11,7 +11,7 @@ bar2.plot<-function(x, y, file, var.label.x, var.label.y, ...)
     onefile<- dots.args$onefile    
 
   if (is.null(file))
-    dev.new()
+    {} #dev.new()
   else {
     if (length(grep("bmp$",file)))
       bmp(file,...) 
